import requests
import json
from .resultclass import BroadbandResult
from .addressmatch import UKBroadbandAddressMatcher

class HeyBroadbandChecker:
    def __init__(
        self,
        checkerAddress="https://heybroadband.co.uk/offer-admin/app/public/rest/uprns",
        authHeader="EKk5w3PmOwLP4rTcbLm6Pz2nLMphY529NkJcKAh71ad3BQSyVe0YQwQOx7FlGzE8",
    ):
        self.checkerAddress = checkerAddress
        self.authHeader = authHeader


    def query_address(self, postCode, houseNumber, strictAddress=True):
        address_list = requests.get(
            f'{self.checkerAddress}',
            params={
            "filter[address_zip]": postCode,
            },
            headers={
                "authorization": f"Bearer {self.authHeader}",
            },
        )

        premiseCheckList = json.loads(address_list.text)['data']
        premiseCheckArray = []
        for thisAddress in premiseCheckList:
            premiseCheckArray.append({
                "addressLine": thisAddress['address'],
                "returnValue": thisAddress,
            })

        if len(premiseCheckList) > 0:
            premise, strictMatched = UKBroadbandAddressMatcher(
                houseNumber,
                postCode,
                premiseCheckArray
            )
        else:
            returnResult = BroadbandResult(
                data={
                    "addressData": False,
                    'serviceable': False,
                    'success': True,
                    'fttp': False,
                    'planned': False,
                },
            )
            return returnResult

        if not strictMatched:
            if strictAddress:
                returnResult = BroadbandResult(
                    data={
                        "addressData": False,
                        'serviceable': False,
                        'success': False,
                        'fttp': False,
                    },
                )
                return returnResult
            else:
                premise['looseMatch'] = True

        returnData = {
            "addressData": premise,
            "message": premise['state'],
            'serviceable': False,
            'planned': False,
            'success': False,
            'fttp': False,
        }

        if premise['state'] == "Design":
            returnData.update({
                'planned': True,
                'success': True,
            })
        elif premise['state'] == "Installed":
            returnData.update({
                'serviceable': True,
                'planned': True,
                'success': True,
                'fttp': True,
            })
        else:
            returnData.update({
                'success': True,
            })

        returnResult = BroadbandResult(
            data=returnData,
        )
        returnResult.fttp = returnData['serviceable']

        return returnResult
